@@ -15,11 +15,11 @@ WG::API - Module for work with Wargaming.net Public API
 
 =head1 VERSION
 
-Version v0.04
+Version v0.05
 
 =cut
 
-our $VERSION = 'v0.04';
+our $VERSION = 'v0.05';
 
 
 =head1 SYNOPSIS
@@ -224,7 +224,7 @@ sub _parse {
                 push @{ $self->{ 'response' } }, WG::API::Data->new( $data );
             };
         } else {
-            push @{ $self->{ 'response' } }, $response->{ 'data' };
+            $self->{ 'response' } = WG::API::Data->new( $response->{ 'data' } );
         }
     }
 
